@@ -336,16 +336,16 @@ public class OpenLayersMap {
 		MousePositionOutput mpOut = new MousePositionOutput() {
 			@Override
 			public String format(LonLat lonLat, Map map) {
-				String out = "<table bgcolor=\"#4B79B4\">";
+				String out = "<table style=\"background-color:#4B79B4 !important;\">";
 				out += "<tr><td>";
 				out += "<font color=\"#FFFFFF\" align=\"left\"><b>Latitude</b></font></td>";
-				out += "<td bgcolor=\"#D9D9DF\"><font style=\"padding: 5px;\" color=\"#9694A2\"><b>";
+				out += "<td style=\"background-color:#D9D9DF !important;\"><font style=\"padding: 5px;\" color=\"#9694A2\"><b>";
 				out += Util.getFormattedLonLat(lonLat.lat(), "", "");
 				// out += lonLat.lat();
 				out += "</b></font></td>";
 				out += "<td>";
 				out += "<font color=\"#FFFFFF\" align=\"left\"><b>Longitude</b></font></td>";
-				out += "<td bgcolor=\"#D9D9DF\"><font style=\"padding: 5px;\" color=\"#9694A2\"><b>";
+				out += "<td style=\"background-color:#D9D9DF !important;\"><font style=\"padding: 5px;\" color=\"#9694A2\"><b>";
 				out += Util.getFormattedLonLat(lonLat.lon(), "lon", "");
 				// out += lonLat.lon();
 				out += "</b></font></td></tr>";
@@ -741,7 +741,7 @@ public class OpenLayersMap {
 		
 		for (GisViewerBaseLayerInterface baseLayerInterface : layers) {
 			if(baseLayerInterface.isDisplay())
-				addBaseLayerToOpenLayerMap(baseLayerInterface.getTitle(), baseLayerInterface.getName(), baseLayerInterface.getWmsURL());
+				addBaseLayerToOpenLayerMap(baseLayerInterface.getTitle(), baseLayerInterface.getName(), baseLayerInterface.getWmsServiceBaseURL());
 		}
 		
 		
@@ -804,16 +804,16 @@ public class OpenLayersMap {
 	/**
 	 * @param title
 	 * @param layerName
-	 * @param url
+	 * @param geoserverBaseUrl
 	 */
-	private void addBaseLayerToOpenLayerMap(String title, String layerName, String url) {
-		if (url==null || url.equals("") || layerName==null || layerName.equals(""))
+	private void addBaseLayerToOpenLayerMap(String title, String layerName, String geoserverBaseUrl) {
+		if (geoserverBaseUrl==null || geoserverBaseUrl.equals("") || layerName==null || layerName.equals(""))
 			return;
 		LayerItem l = new LayerItem(true);
 		l.setTitle(title);
 		l.setName(layerName);
 		l.setLayer(layerName);
-		l.setGeoserverWmsUrl(url);
+		l.setGeoserverWmsUrl(geoserverBaseUrl);
 		l.setBaseLayer(true);
 		l.setOpacity(1d);
 		addLayerItemByWms(l, true);
@@ -826,23 +826,36 @@ public class OpenLayersMap {
 	public void addLayerItemByWms(LayerItem layerItem, boolean displayInLayerSwitcher) {
 		WMSOptions wmsOptions = new WMSOptions();
 		wmsOptions.setIsBaseLayer(layerItem.isBaseLayer());
-		wmsOptions.setBuffer(2); // from serviceimpl
 		wmsOptions.setWrapDateLine(true); // default
+//		wmsOptions.setTransitionEffect(TransitionEffect.RESIZE);
+		
 		WMSParams wmsParams = new WMSParams();
 		wmsParams.setLayers(layerItem.getLayer());
 		wmsParams.setIsTransparent(!layerItem.isBaseLayer());
 		wmsParams.setFormat("image/png");
-		//wmsParams.setMaxExtent(defaultBounds);
 		
 		
-		Layer layer = new WMS(layerItem.getTitle(), layerItem.getGeoserverWmsUrl(), wmsParams, wmsOptions);
-
-
-		//TODO
-
-//		System.out.println("layer.getJSObject().toString() "+layer.getJSObject().createJSObject().toString());
+		if(layerItem.getWmsNotStandardParams()!=null){ //LAYER CANNOT BE TILED
+			for (String key : layerItem.getWmsNotStandardParams().keySet()) {
+				String value = layerItem.getWmsNotStandardParams().get(key);
+				wmsParams.setParameter(key, value);
+//				{"min":-55.33762,"max":2474.535}
+//				wmsParams.setParameter(key, "-42.581142,1829.7272");
+//				wmsParams.setParameter(key, "-55.33762,2474.535");
+				GWT.log("Added non-standard pair to wms request: "+key+"/"+value);
+			}
+//			wmsOptions.setUntiled();
+//			wmsOptions.setSingleTile(true);
+//			wmsParams.setParameter("version", "1.3.0");
+//			wmsParams.setParameter("CRS", "EPSG:4326");
+//			wmsParams.setParameter("SRS", "EPSG:4326");
+//			wmsParams.setParameter("BBOX", "-415.283203125,-109.951171875,415.283203125,109.951171875");
+		}else //LAYER CAB BE TILED
+			wmsOptions.setBuffer(2); // from serviceimpl
+		
+		
+		WMS layer = new WMS(layerItem.getTitle(), layerItem.getGeoserverWmsUrl(), wmsParams, wmsOptions);
 		
-
 		layer.setDisplayInLayerSwitcher(displayInLayerSwitcher);
 		mappingLayerItemsToLayers.put(layerItem, layer);
 		mappingLayersToLayerItems.put(layer, layerItem);
